@@ -57,6 +57,10 @@ class NlP(object):
     def summary(text: str, ratio: float = 0.5) -> str:
         return Talk.tfidf_summarization(sentence=text, ratio=ratio)
 
+    @staticmethod
+    def keyPhrase(text: str,) -> str:
+        return Talk.keyPhraseExtraction(sentence=text)
+
     @staticmethod
     def nlp_filter_list(prompt, material: list):
         if not material or not isinstance(material, list):
